@@ -17,11 +17,11 @@ console = getConsole()
 
 #Class definitions
 class Monitor(tasking.Tasker):
-    """Monitor Task Patron Registry Class for monitoring IP host port  
+    """Monitor Task Patron Registry Class for monitoring IP host port
 
-       Usage:   
+       Usage:
     """
-    #Counter = 0  
+    #Counter = 0
     #Names = {}
 
     def __init__(self, host = '', port = 23456, dhost = '10.0.2.162', dport = 23456, **kw):
@@ -29,17 +29,17 @@ class Monitor(tasking.Tasker):
 
            iherited instance attributes
            .name = unique name for machine
-           .store = data store 
+           .store = data store
 
            .period = desired time in seconds between runs must be non negative, zero means asap
-           .stamp = time when tasker last ran, 
+           .stamp = time when tasker last ran,
            .status = operational status of tasker
            .desire = desired control asked by this or other taskers
            .done = tasker completion state True or False
            .runner = generator to run tasker
 
            instance attributes
-           .console = nonblocking io console object 
+           .console = nonblocking io console object
            .host = host
            .port = port
            .ha = host port tuple
@@ -55,7 +55,7 @@ class Monitor(tasking.Tasker):
         self.host = host
         self.port = port
         self.ha = (self.host, self.port)
-        self.server = aiding.SocketNB(host = self.host,port = self.port, path = '')
+        self.server = aiding.SocketUdpNb(host = self.host,port = self.port, path = '')
 
         self.dha = (dhost, dport) #set up destination address
 
@@ -72,7 +72,7 @@ class Monitor(tasking.Tasker):
     def close(self):
         """Close open connections"""
         self.server.close()
-        self.console.close() #close file descriptor to console      
+        self.console.close() #close file descriptor to console
 
 
     def makeRunner(self):
@@ -89,12 +89,12 @@ class Monitor(tasking.Tasker):
                 console.profuse("\n     Iterate Monitor {0} with control = {1} status = {2}\n".format(
                     self.name,
                     ControlNames.get(control, 'Unknown'),
-                    StatusNames.get(self.status, 'Unknown')))         
+                    StatusNames.get(self.status, 'Unknown')))
 
                 self.desire = RUN #default what to do next time, override in frame
 
                 if control == RUN:
-                    if self.status == STARTED or self.status == RUNNING:          
+                    if self.status == STARTED or self.status == RUNNING:
                         self.status = RUNNING
                         console.profuse("     Running Monitor {0} ...\n".format(self.name))
 
@@ -127,7 +127,7 @@ class Monitor(tasking.Tasker):
 
                 elif control == READY:
                     self.status = READIED
-                    console.profuse("     Readying Monitor {0} ...\n".format(self.name))   
+                    console.profuse("     Readying Monitor {0} ...\n".format(self.name))
 
                 elif control == START:
                     self.status = STARTED
@@ -171,9 +171,9 @@ class Monitor(tasking.Tasker):
             self.close()
 
 class MonitorOut(Monitor):
-    """MonitorOut Monitor Task Patron Registry Class for sending to ip host port  
+    """MonitorOut Monitor Task Patron Registry Class for sending to ip host port
 
-       Usage:   
+       Usage:
     """
 
 
@@ -182,16 +182,16 @@ class MonitorOut(Monitor):
 
            iherited instance attributes
            .name = unique name for machine
-           .store = data store 
+           .store = data store
 
            .period = desired time in seconds between runs must be non negative, zero means asap
-           .stamp = time when tasker last ran, 
+           .stamp = time when tasker last ran,
            .status = operational status of tasker
            .done = tasker completions state True or False
            .desire = desired control asked by this or other taskers
            .runner = generator to run tasker
 
-           .console = nonblocking io console object 
+           .console = nonblocking io console object
            .host = host
            .port = port
            .ha = host port tuple
@@ -199,7 +199,7 @@ class MonitorOut(Monitor):
            .dha = destination address (host, port)
         """
 
-        super(MonitorOut,self).__init__(host = host, port = port, dhost = dhost, dport = dport, **kw) 
+        super(MonitorOut,self).__init__(host = host, port = port, dhost = dhost, dport = dport, **kw)
 
 
 
@@ -217,14 +217,14 @@ class MonitorOut(Monitor):
             console.profuse("Iterate Monitor {0} with control = {1} status = {2}\n".format(
                 self.name,
                 ControlNames.get(control, 'Unknown'),
-                StatusNames.get(self.status, 'Unknown')))            
+                StatusNames.get(self.status, 'Unknown')))
 
             self.desire = RUN #default what to do next time, override in frame
             self.stamp = self.store.stamp
 
             if control == RUN:
                 self.status = RUNNING
-                console.profuse("Running Monitor {0} ...\n".format(self.name))   
+                console.profuse("Running Monitor {0} ...\n".format(self.name))
 
                 #line = self.console.getLine().strip()
                 line = self.console.getLine()
@@ -232,7 +232,7 @@ class MonitorOut(Monitor):
                 if line:
                     if line[0].lower() == 's':
                         self.status = STOPPED
-                        console.profuse("Stopping Monitor {0} ...\n".format(self.name))   
+                        console.profuse("Stopping Monitor {0} ...\n".format(self.name))
 
                         self.server.close()
                         self.console.close() #close file descriptor to console
@@ -244,11 +244,11 @@ class MonitorOut(Monitor):
 
             elif control == READY:
                 self.status = READIED
-                console.profuse("Readying Monitor {0} ...\n".format(self.name))   
+                console.profuse("Readying Monitor {0} ...\n".format(self.name))
 
             elif control == START:
                 self.status = STARTED
-                console.profuse("Starting Monitor {0} ...\n".format(self.name))   
+                console.profuse("Starting Monitor {0} ...\n".format(self.name))
 
                 self.console.open() #reopen file descriptor to console
                 self.server.open() #open socket server
@@ -256,7 +256,7 @@ class MonitorOut(Monitor):
 
             elif control == STOP:
                 self.status = STOPPED
-                console.profuse("Stopping Monitor {0} ...\n".format(self.name))   
+                console.profuse("Stopping Monitor {0} ...\n".format(self.name))
 
                 self.server.close()
                 self.console.close() #close file descriptor to console
@@ -264,7 +264,7 @@ class MonitorOut(Monitor):
 
             elif control == ABORT:
                 self.status = ABORTED
-                console.profuse("Aborting Monitor {0} ...\n".format(self.name))   
+                console.profuse("Aborting Monitor {0} ...\n".format(self.name))
 
                 self.server.close()
                 self.console.close() #close file descriptor to console
@@ -279,7 +279,7 @@ class MonitorOut(Monitor):
                 self.server.close()
                 self.console.close() #close file descriptor to console
                 self.done = True
-                break #break out of while loop. this will cause stopIteration         
+                break #break out of while loop. this will cause stopIteration
 
 
 def TestOut():
@@ -288,7 +288,7 @@ def TestOut():
 
 
     """
-    
+
     m = MonitorOut(store = storing.Store())
     print "ready to go"
     status = m.start()
